==> raml-defined-example-3.0.4-sources.jar: example/model/HumanIdImpl.java <==
package example.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.Map;
import java.util.Objects;
import javax.validation.constraints.NotNull;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "serial",
    "type"
})
public class HumanIdImpl implements HumanId {
  @JsonProperty("serial")
  @NotNull
  private String serial;

  @JsonProperty("type")
  @NotNull
  private String type;

  @JsonIgnore
  private Map<String, Object> additionalProperties = new ExcludingMap();

  @JsonProperty("serial")
  public String getSerial() {
    return this.serial;
  }

  @JsonProperty("serial")
  public void setSerial(String serial) {
    this.serial = serial;
  }

  @JsonProperty("type")
  public String getType() {
    return this.type;
  }

  @JsonProperty("type")
  public void setType(String type) {
    this.type = type;
  }

  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  @JsonAnySetter
  public void setAdditionalProperties(String key, Object value) {
    this.additionalProperties.put(key, value);
  }

  @Override
  public boolean equals(Object o) {
    if (o == null) return false;
    if (this == o) return true;
    if (getClass() != o.getClass()) return false;
    HumanIdImpl other = (HumanIdImpl) o;
    return java.util.Objects.equals(this.serial, other.serial) && java.util.Objects.equals(this.type, other.type) && java.util.Objects.equals(this.additionalProperties, other.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(serial,type,additionalProperties);
  }
}

==> raml-defined-example-3.0.5-sources.jar: example/model/HumanIdImpl.java <==
package example.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.Map;
import java.util.Objects;
import javax.validation.constraints.NotNull;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "serial",
    "type"
})
public class HumanIdImpl implements HumanId {
  @NotNull
  @JsonProperty("serial")
  private String serial;

  @JsonProperty("type")
  @NotNull
  private String type;

  @JsonIgnore
  private Map<String, Object> additionalProperties = new ExcludingMap();

  @JsonProperty("serial")
  public String getSerial() {
    return this.serial;
  }

  @JsonProperty("serial")
  public void setSerial(String serial) {
    this.serial = serial;
  }

  @JsonProperty("type")
  public String getType() {
    return this.type;
  }

  @JsonProperty("type")
  public void setType(String type) {
    this.type = type;
  }

  @Override
  public boolean equals(Object o) {
    if (o == null) return false;
    if (this == o) return true;
    if (getClass() != o.getClass()) return false;
    HumanIdImpl other = (HumanIdImpl) o;
    return java.util.Objects.equals(this.serial, other.serial) && java.util.Objects.equals(this.type, other.type);
  }

  @Override
  public int hashCode() {
    return Objects.hash(serial,type);
  }

  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  @JsonAnySetter
  public void setAdditionalProperties(String key, Object value) {
    this.additionalProperties.put(key, value);
  }
}
